@@ -23,13 +23,13 @@
 
 #include <gdk/gdkkeysyms.h>
 #include <gdk/gdkkeys.h>
-#include <gtkimcontextthai.h>
+#include "gtkimcontextthai.h"
 
 #include <thai/thcell.h>
 #include <thai/thinp.h>
 
 static void     gtk_im_context_libthai_class_init      (GtkIMContextLibThaiClass *class);
-static void     gtk_im_context_libthai_init            (GtkIMContextLibThai      *im_context_xim);
+static void     gtk_im_context_libthai_init            (GtkIMContextLibThai      *im_context_libthai);
 static gboolean gtk_im_context_libthai_filter_keypress (GtkIMContext             *context,
 						        GdkEventKey              *key);
 
@@ -295,7 +295,9 @@ gtk_im_context_libthai_filter_keypress (GtkIMContext *context,
           if (!gtk_im_context_delete_surrounding (GTK_IM_CONTEXT (context_libthai),
                                                   conv.offset, -conv.offset))
             {
-              return FALSE;
+              /* Can't correct context, just fall back to rejection */
+              gdk_beep ();
+              return TRUE;
             }
         }
 #ifndef GTK_IM_CONTEXT_LIBTHAI_NO_FALLBACK
